from setuptools import setup, find_packages

setup(
    name='My-unique-project00',
    version='0.1.999',
    packages=find_packages(),
    install_requires=[],
    license='',
    author='Moshaddak Hasan',
    author_email='sakib1234@gmail.com',
    description='This is a sample Python package',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
    ],
    python_requires='>=3.0',


    )
